@@ -3,7 +3,7 @@ package Chrome::Util::Profile;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-19'; # DATE
 our $DIST = 'Chrome-Util-Profile'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,7 +68,7 @@ sub list_chrome_profiles {
     }
 
     unless ($args{detail}) {
-        @rows = [map { $_->{name} } @rows];
+        @rows = map { $_->{name} } @rows;
     }
 
     [200, "OK", \@rows, $resmeta];
@@ -89,7 +89,7 @@ Chrome::Util::Profile - List available Google Chrome profiles
 
 =head1 VERSION
 
-This document describes version 0.002 of Chrome::Util::Profile (from Perl distribution Chrome-Util-Profile), released on 2020-04-19.
+This document describes version 0.003 of Chrome::Util::Profile (from Perl distribution Chrome-Util-Profile), released on 2020-04-19.
 
 =head1 SYNOPSIS
 
